RadNLP (*Rad*\ iology NLP)
==========================

NLP scripts etc for Radiology projects using
`pyConTextNLP <https://github.com/chapmanbe/pyConTextNLP>`__

Tutorials
---------

See the `notebooks folder <./notebooks>`__ for a series of walkthroughs
demonstrating radnlp core concepts with example data.
